@@ -20,6 +20,7 @@ order_names <- function(old_names, new_names) {
 #' @param ... force later arguments to bind by name
 #' @param mods SQL modifiers (GROUP BY, ORDER BY, and so on)
 #' @param orig_columns logical if TRUE select all original columns.
+#' @param env environment to look to.
 #' @return sql node.
 #'
 #' @examples
@@ -83,7 +84,8 @@ order_names <- function(old_names, new_names) {
 sql_node <- function(source, exprs,
                      ...,
                      mods = NULL,
-                     orig_columns = TRUE) {
+                     orig_columns = TRUE,
+                     env = parent.frame()) {
   wrapr::stop_if_dot_args(substitute(list(...)), "sql_node")
   UseMethod("sql_node", source)
 }
@@ -92,7 +94,8 @@ sql_node <- function(source, exprs,
 sql_node.relop <- function(source, exprs,
                            ...,
                            mods = NULL,
-                           orig_columns = TRUE) {
+                           orig_columns = TRUE,
+                           env = parent.frame()) {
   wrapr::stop_if_dot_args(substitute(list(...)), "sql_node.relop")
   names_used <- Filter(is.name, unlist(exprs,
                                        recursive = TRUE,
@@ -127,14 +130,15 @@ sql_node.relop <- function(source, exprs,
 sql_node.data.frame <- function(source, exprs,
                                 ...,
                                 mods = NULL,
-                                orig_columns = TRUE) {
+                                orig_columns = TRUE,
+                                env = parent.frame()) {
   wrapr::stop_if_dot_args(substitute(list(...)), "sql_node.data.frame")
   tmp_name <- mk_tmp_name_source("rquery_tmp")()
   dnode <- mk_td(tmp_name, colnames(source))
   enode <- sql_node(dnode, exprs = exprs,
                     mods = mods,
                     orig_columns = orig_columns)
-  return(enode)
+  rquery_apply_to_data_frame(source, enode, env = env)
 }
 
 
